==> dasu_3.02.jar: edu/northwestern/dasu/ui/LinePlot.java <==
package edu.northwestern.dasu.ui;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import edu.northwestern.dasu.util.Pair;

public class LinePlot implements Serializable {
	
	public static final int FORMAT_TIME=1;
	public static final int FORMAT_DATE=2;
	public static final int FORMAT_DAY_WEEK=3;
	public static final int FORMAT_MONTH=4;
	public static final int FORMAT_NUMBER=5;
	
	private HashMap<String, ArrayList<Pair<Long, Float>>> series = new HashMap();
	private HashMap<String, Object> options = new HashMap<String, Object>();
	
	private boolean showHighlight;
	private long x1Highlight;
	private long x2Highlight;

	private String id = "";
	private String xLabel = "";
	private String yLabel = "";
	private int xLabelFormat = FORMAT_TIME; //default is time;
		
	public LinePlot(){
	}
	
	public LinePlot(String id, String plotTitle, Collection<Long> xValues, Collection<Float> yValues, 
			String xLabel, String yLabel, int xLabelFormat) {
		
		this.id = id;
		ArrayList<Long> xAxis = genXaxis(xValues, yValues);			
		ArrayList<Pair<Long, Float>> dataValues = new ArrayList<Pair<Long, Float>>();
		
		Iterator<Long> xIter = xAxis.iterator();
		Iterator<Float> yIter = yValues.iterator();
		while (xIter.hasNext()) {
			dataValues.add(new Pair<Long, Float>(xIter.next(), yIter.next()));
		}
		
		if (dataValues.size() > 0) {
						
			if (plotTitle == null)
				plotTitle = "default";
			
			if (xLabel != null)
				this.xLabel = xLabel;
			
			if (yLabel != null)
				this.yLabel = yLabel;
						
			series.put(plotTitle, dataValues);
			setXLabelFormat(xLabelFormat);
			
		}
		
	}
	
	public LinePlot(ArrayList<Pair<Long,Float>> dataValues,String plotTitle, String xlabel, 
			String ylabel, int xLabelFormat){
				
		if (plotTitle == null)
			plotTitle = "default";
		
		if (xlabel != null)
			this.xLabel = xlabel;
		
		if (ylabel != null)
			this.yLabel = ylabel;
		
		series.put(plotTitle, dataValues);		
		setXLabelFormat(xLabelFormat);
		
	}
	
	public void addOption( String name, Object val) {
		options.put(name, val);
	}
				
	private ArrayList<Long> genXaxis(Collection<Long> xValues, Collection<Float> yValues) {
		
		ArrayList<Long> xAxis = new ArrayList<Long>();

		if (xValues != null) {
			
			Iterator<Long> iter = xValues.iterator();
			long first = iter.next();
			long last = first;
			while (iter.hasNext())
				last = iter.next();

			if (last == first) {			
				
				for (long i=1; i<= yValues.size(); i++)
					xAxis.add(i);
			}
			else {
				xAxis = new ArrayList<Long>(xValues);
			}
		}
		else {
			for (long i=1; i<= yValues.size(); i++)
				xAxis.add(i);
		}
		
		return xAxis;
	}
	
	public boolean addSeries(String title, Collection<Float> yValues) {
		
		ArrayList<Pair<Long, Float>> points = 
			(ArrayList<Pair<Long, Float>>) series.values().toArray()[0];

		if ( yValues.size() != points.size()) {	
			System.out.println("series is not the same length as original");
			return false;
		}
		
		ArrayList<Long> xAxis = new ArrayList<Long>();
		for ( int i=0; i < points.size(); i++)
			xAxis.add(points.get(i).getKey());
		
		ArrayList<Pair<Long, Float>> dataValues = new ArrayList<Pair<Long, Float>>();
		
		Iterator<Long> xIter = xAxis.iterator();
		Iterator<Float> yIter = yValues.iterator();
		while (xIter.hasNext()) {
			dataValues.add(new Pair<Long, Float>(xIter.next(), yIter.next()));
		}
		
		if (dataValues.size() > 0) {
			series.put(title, new ArrayList<Pair<Long, Float>>());
			series.get(title).addAll(dataValues);						
			return true;
		}

		return false;		
		
	}
	
	private String toLabel(Long timestamp) {
		
		//create an array of days
	    String[] strDays = new String[]{ "Sun", "Mon", "Tue", "Wed", "Thr", "Fri", "Sat"};
	 
		//create an array of months
	    String[] strMonths = new String[]{ "Jan", "Feb",  "Mar", "Apr", "May", "Jun",
	                      "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
	    
		Calendar cal = Calendar.getInstance();
		cal.setTimeInMillis(timestamp);
		
		if (xLabelFormat == LinePlot.FORMAT_DAY_WEEK)
			return strDays[(cal.get(Calendar.DAY_OF_WEEK) -1)];
		
		else if (xLabelFormat == LinePlot.FORMAT_MONTH)
			return strMonths[(cal.get(Calendar.MONTH) -1)];

		else if (xLabelFormat == LinePlot.FORMAT_TIME) {
			String t = cal.get(Calendar.HOUR_OF_DAY) + ":" + 
				cal.get(Calendar.MINUTE) + ":" + cal.get(Calendar.SECOND);
			
			return t;
		}
		
		else
			return timestamp.toString();
				
	}
	
	private ArrayList<Object> genSeries(ArrayList<Pair<Long, Float>> points) {

		ArrayList<Object> plot = new ArrayList<Object>();
		for (int i=0; i < points.size(); i++) {
			Pair<Long, Float> p = points.get(i);
			ArrayList<Object> point = new ArrayList<Object>();

			//if ( graphType != HVPlot.FORMAT_NUMBER )
			//	point.add(toLabel(p.getKey()));
			//else
			point.add(i);			
			point.add(p.getValue());
			plot.add(point);
		}

		return plot;
	}
	
	private HashMap<String, Object> genSeriesMap(String label, 
			ArrayList<Pair<Long, Float>> points) {
		
		HashMap<String, Object> plotMap = new HashMap<String, Object>();		
		plotMap.put("label", label);
		plotMap.put("data", genSeries(points));
		return plotMap;
		
	}
	
	public ArrayList<Object> generatePlot() {
	
		ArrayList<Object> w1 = new ArrayList<Object>();
		
		for ( String name : series.keySet() )
			w1.add(genSeriesMap(name, series.get(name)));
		
		ArrayList<Object> w2 = new ArrayList<Object>();
		w2.add(w1);
		w2.add(options);
				
		return w2;
	}
	
	public void setXLabelFormat(int format) {
		
		if (format >= 1 && format <= 5)
			xLabelFormat = format; 
	}
	
	public int getXLabelFormat() {
		return xLabelFormat;
	}
	
	public void HighlightSection(long x1, long x2){
		showHighlight = true;
		x1Highlight = x1;
		x2Highlight = x2;
	}
	
	public ArrayList<Pair<Long, Float>> getSeires(String seriesName) {

		if (seriesName != null) {
			if ( series.containsKey(seriesName))
				return series.get(seriesName);
		}
		return null;
	}
	
	public void setXLabel(String xlabel){
		this.xLabel = xlabel;
	}
	
	public void setYLabel(String ylabel){
		this.yLabel = ylabel;
	}
	
	public String getXLabel(){
		return xLabel;
	}
	
	public String getyLabel(){
		return yLabel;
	}

	public boolean isShowHighlight() {
		return showHighlight;
	}

	public void setShowHighlight(boolean showHighlight) {
		this.showHighlight = showHighlight;
	}

	public long getX1Highlight() {
		return x1Highlight;
	}

	public void setX1Highlight(int x1Highlight) {
		this.x1Highlight = x1Highlight;
	}

	public long getX2Highlight() {
		return x2Highlight;
	}

	public void setX2Highlight(int x2Highlight) {
		this.x2Highlight = x2Highlight;
	}

	public String getxLabel() {
		return xLabel;
	}

	public void setxLabel(String xLabel) {
		this.xLabel = xLabel;
	}

	public void setyLabel(String yLabel) {
		this.yLabel = yLabel;
	}

	public HashMap<String, ArrayList<Pair<Long, Float>>> getSeries() {
		return series;
	}

	public void setSeries(HashMap<String, ArrayList<Pair<Long, Float>>> series) {
		this.series = series;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getYLabel() {
		return yLabel;
	}
	
}

==> dasu_4.11.jar: edu/northwestern/dasu/ui/LinePlot.java <==
package edu.northwestern.dasu.ui;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import edu.northwestern.dasu.util.Pair;

public class LinePlot implements Serializable {
	
	public static final int FORMAT_TIME=1;
	public static final int FORMAT_DATE=2;
	public static final int FORMAT_DAY_WEEK=3;
	public static final int FORMAT_MONTH=4;
	public static final int FORMAT_NUMBER=5;
	
	private HashMap<String, ArrayList<Pair<Long, Float>>> series = new HashMap();
	private HashMap<String, Object> options = new HashMap<String, Object>();
	
	private boolean showHighlight;
	private long x1Highlight;
	private long x2Highlight;

	private String id = "";
	private String xLabel = "";
	private String yLabel = "";
	private int xLabelFormat = FORMAT_TIME; //default is time;
		
	public LinePlot(){
	}
	
	public LinePlot(String id, String plotTitle, Collection<Long> xValues, Collection<Float> yValues, 
			String xLabel, String yLabel, int xLabelFormat) {
		
		this.id = id;
		ArrayList<Long> xAxis = genXaxis(xValues, yValues);			
		ArrayList<Pair<Long, Float>> dataValues = new ArrayList<Pair<Long, Float>>();
		
		Iterator<Long> xIter = xAxis.iterator();
		Iterator<Float> yIter = yValues.iterator();
		while (xIter.hasNext()) {
			dataValues.add(new Pair<Long, Float>(xIter.next(), yIter.next()));
		}
		
		if (dataValues.size() > 0) {
						
			if (plotTitle == null)
				plotTitle = "default";
			
			if (xLabel != null)
				this.xLabel = xLabel;			
						
			if (yLabel != null) 
				this.yLabel = yLabel;			
						
			series.put(plotTitle, dataValues);
			setXLabelFormat(xLabelFormat);
			addOption("plotTitle", plotTitle);
			
		}
		
	}
	
	public LinePlot(ArrayList<Pair<Long,Float>> dataValues,String plotTitle, String xlabel, 
			String ylabel, int xLabelFormat){
				
		if (plotTitle == null)
			plotTitle = "default";
		
		if (xlabel != null)
			this.xLabel = xlabel;
		
		if (ylabel != null)
			this.yLabel = ylabel;
		
		series.put(plotTitle, dataValues);		
		setXLabelFormat(xLabelFormat);
		
	}
	
	public void enableAxisTitles() {
			
		if (xLabel != null) {			
			HashMap<String, Object> axisLabels = new HashMap();
			axisLabels.put("axisLabel", xLabel);
			axisLabels.put("axisLabelUseCanvas", true);
			axisLabels.put("axisLabelFontSizePixels", 16);
			addOption("xaxis", axisLabels);			
		}
		
		if (yLabel != null) {
			HashMap<String, Object> axisLabels = new HashMap();
			axisLabels.put("axisLabel", yLabel);
			axisLabels.put("axisLabelUseCanvas", true);
			axisLabels.put("axisLabelFontSizePixels", 16);
			addOption("yaxis", axisLabels);
		}

	}
	
	
	public void addOption( String name, Object val) {
		options.put(name, val);
	}
				
	private ArrayList<Long> genXaxis(Collection<Long> xValues, Collection<Float> yValues) {
		
		ArrayList<Long> xAxis = new ArrayList<Long>();

		if (xValues != null) {
			
			Iterator<Long> iter = xValues.iterator();
			long first = iter.next();
			long last = first;
			while (iter.hasNext())
				last = iter.next();

			if (last == first) {			
				
				for (long i=1; i<= yValues.size(); i++)
					xAxis.add(i);
			}
			else {
				xAxis = new ArrayList<Long>(xValues);
			}
		}
		else {
			for (long i=1; i<= yValues.size(); i++)
				xAxis.add(i);
		}
		
		return xAxis;
	}
	
	public boolean addSeries(String title, Collection<Float> yValues) {
		
		ArrayList<Pair<Long, Float>> points = 
			(ArrayList<Pair<Long, Float>>) series.values().toArray()[0];

		if ( yValues.size() != points.size()) {	
			System.out.println("series is not the same length as original");
			return false;
		}
		
		ArrayList<Long> xAxis = new ArrayList<Long>();
		for ( int i=0; i < points.size(); i++)
			xAxis.add(points.get(i).getKey());
		
		ArrayList<Pair<Long, Float>> dataValues = new ArrayList<Pair<Long, Float>>();
		
		Iterator<Long> xIter = xAxis.iterator();
		Iterator<Float> yIter = yValues.iterator();
		while (xIter.hasNext()) {
			dataValues.add(new Pair<Long, Float>(xIter.next(), yIter.next()));
		}
		
		if (dataValues.size() > 0) {
			series.put(title, new ArrayList<Pair<Long, Float>>());
			series.get(title).addAll(dataValues);						
			return true;
		}

		return false;		
		
	}
	
	private String toLabel(Long timestamp) {
		
		//create an array of days
	    String[] strDays = new String[]{ "Sun", "Mon", "Tue", "Wed", "Thr", "Fri", "Sat"};
	 
		//create an array of months
	    String[] strMonths = new String[]{ "Jan", "Feb",  "Mar", "Apr", "May", "Jun",
	                      "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
	    
		Calendar cal = Calendar.getInstance();
		cal.setTimeInMillis(timestamp);
		
		if (xLabelFormat == LinePlot.FORMAT_DAY_WEEK)
			return strDays[(cal.get(Calendar.DAY_OF_WEEK) -1)];
		
		else if (xLabelFormat == LinePlot.FORMAT_MONTH)
			return strMonths[(cal.get(Calendar.MONTH) -1)];

		else if (xLabelFormat == LinePlot.FORMAT_TIME) {
			String t = cal.get(Calendar.HOUR_OF_DAY) + ":" + 
				cal.get(Calendar.MINUTE) + ":" + cal.get(Calendar.SECOND);
			
			return t;
		}
		
		else
			return timestamp.toString();
				
	}
	
	private ArrayList<Object> genSeries(ArrayList<Pair<Long, Float>> points) {

		ArrayList<Object> plot = new ArrayList<Object>();
		for (int i=0; i < points.size(); i++) {
			Pair<Long, Float> p = points.get(i);
			ArrayList<Object> point = new ArrayList<Object>();

			//if ( graphType != HVPlot.FORMAT_NUMBER )
			//	point.add(toLabel(p.getKey()));
			//else
			point.add(i);			
			point.add(p.getValue());
			plot.add(point);
		}

		return plot;
	}
	
	private HashMap<String, Object> genSeriesMap(String label, 
			ArrayList<Pair<Long, Float>> points) {
		
		HashMap<String, Object> plotMap = new HashMap<String, Object>();		
		plotMap.put("label", label);
		plotMap.put("data", genSeries(points));
		return plotMap;
		
	}
	
	public ArrayList<Object> generatePlot() {
	
		ArrayList<Object> w1 = new ArrayList<Object>();
		
		for ( String name : series.keySet() )
			w1.add(genSeriesMap(name, series.get(name)));
		
		ArrayList<Object> w2 = new ArrayList<Object>();
		w2.add(w1);				
		w2.add(options);
				
		return w2;
	}
	
	public void setXLabelFormat(int format) {
		
		if (format >= 1 && format <= 5)
			xLabelFormat = format; 
	}
	
	public int getXLabelFormat() {
		return xLabelFormat;
	}
	
	public void HighlightSection(long x1, long x2){
		showHighlight = true;
		x1Highlight = x1;
		x2Highlight = x2;
	}
	
	public ArrayList<Pair<Long, Float>> getSeries(String seriesName) {

		if (seriesName != null) {
			if ( series.containsKey(seriesName))
				return series.get(seriesName);
		}
		return null;
	}
	
	public void setXLabel(String xlabel){
		this.xLabel = xlabel;
	}
	
	public void setYLabel(String ylabel){
		this.yLabel = ylabel;
	}
	
	public String getXLabel(){
		return xLabel;
	}
	
	public String getyLabel(){
		return yLabel;
	}

	public boolean isShowHighlight() {
		return showHighlight;
	}

	public void setShowHighlight(boolean showHighlight) {
		this.showHighlight = showHighlight;
	}

	public long getX1Highlight() {
		return x1Highlight;
	}

	public void setX1Highlight(int x1Highlight) {
		this.x1Highlight = x1Highlight;
	}

	public long getX2Highlight() {
		return x2Highlight;
	}

	public void setX2Highlight(int x2Highlight) {
		this.x2Highlight = x2Highlight;
	}

	public String getxLabel() {
		return xLabel;
	}

	public void setxLabel(String xLabel) {
		this.xLabel = xLabel;
	}

	public void setyLabel(String yLabel) {
		this.yLabel = yLabel;
	}

	public HashMap<String, ArrayList<Pair<Long, Float>>> getSeries() {
		return series;
	}

	public void setSeries(HashMap<String, ArrayList<Pair<Long, Float>>> series) {
		this.series = series;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getYLabel() {
		return yLabel;
	}
	
}
